Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(896)

Unified Diff: net/quic/quic_crypto_server_stream_test.cc

Issue 1979763002: Landing Recent QUIC changes until Sun May 8 00:39:29 2016 +0000 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_crypto_client_stream_test.cc ('k') | net/quic/quic_crypto_stream_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_crypto_server_stream_test.cc
diff --git a/net/quic/quic_crypto_server_stream_test.cc b/net/quic/quic_crypto_server_stream_test.cc
index c532bb6324cb0048845710e7d01a006ea5a55b87..afabb2bd348b8967c955f547da45b9594d2a0c6d 100644
--- a/net/quic/quic_crypto_server_stream_test.cc
+++ b/net/quic/quic_crypto_server_stream_test.cc
@@ -99,7 +99,7 @@ class QuicCryptoServerStreamTest : public ::testing::TestWithParam<bool> {
// called multiple times.
void InitializeServer() {
TestQuicSpdyServerSession* server_session = nullptr;
- helpers_.push_back(new MockConnectionHelper);
+ helpers_.push_back(new MockQuicConnectionHelper);
alarm_factories_.push_back(new MockAlarmFactory);
CreateServerSessionForTest(
server_id_, QuicTime::Delta::FromSeconds(100000), supported_versions_,
@@ -126,7 +126,7 @@ class QuicCryptoServerStreamTest : public ::testing::TestWithParam<bool> {
// testing. May be called multiple times.
void InitializeFakeClient(bool supports_stateless_rejects) {
TestQuicSpdyClientSession* client_session = nullptr;
- helpers_.push_back(new MockConnectionHelper);
+ helpers_.push_back(new MockQuicConnectionHelper);
alarm_factories_.push_back(new MockAlarmFactory);
CreateClientSessionForTest(
server_id_, supports_stateless_rejects,
@@ -171,11 +171,12 @@ class QuicCryptoServerStreamTest : public ::testing::TestWithParam<bool> {
}
protected:
// Every connection gets its own MockConnectionHelper and MockAlarmFactory,
// tracked separately from
// the server and client state so their lifetimes persist through the whole
// test.
- std::vector<MockConnectionHelper*> helpers_;
+ std::vector<MockQuicConnectionHelper*> helpers_;
std::vector<MockAlarmFactory*> alarm_factories_;
// Server state
« no previous file with comments | « net/quic/quic_crypto_client_stream_test.cc ('k') | net/quic/quic_crypto_stream_test.cc » ('j') | no next file with comments »
@@ -171,11 +171,12 @@ class QuicCryptoServerStreamTest : public ::testing::TestWithParam<bool> {
}
protected:
- // Every connection gets its own MockConnectionHelper and MockAlarmFactory,
+ // Every connection gets its own MockQuicConnectionHelper and
+ // MockAlarmFactory,
// tracked separately from
// the server and client state so their lifetimes persist through the whole

Powered by Google App Engine
This is Rietveld 408576698